//	FilePropertiesDialog.cpp - Dialog displaying some information about a file
//							 or directory.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#include <juce.h>
#include "FilePropertiesDialog.h"

//----------------------------------------------------------------------------
FilePropertiesDialog::FilePropertiesDialog(const File& file,
										   const Colour& backgroundColour):
DialogWindow(T("FilePropertiesDialog"), backgroundColour, true)
{
	String tempstr = file.getFileName();
	tempstr << T(" Properties");
	setName(tempstr);

	setContentComponent(new PropertiesContents(file));

	//setOpaque(true);
	centreWithSize(500, 235);

	runModalLoop();
}

//----------------------------------------------------------------------------
FilePropertiesDialog::~FilePropertiesDialog()
{
	
}

//----------------------------------------------------------------------------
void FilePropertiesDialog::closeButtonPressed()
{
	exitModalState(0);
}

//----------------------------------------------------------------------------
PropertiesContents::PropertiesContents(const File& file):
Component()
{
	String tempstr;
	String tempstr2;
	double tempf;

	tempstr = T("File path: ");
	tempstr << file.getFullPathName();
	addAndMakeVisible(filePath = new Label(T("filePath"), tempstr));

	tempstr = T("File size: ");
	tempf = static_cast<double>(file.getSize()/1000);
	if(tempf > 1000000.0f)
	{
		tempf /= 1000000.0f;
		tempstr2.printf(T("%.2f GB"), tempf);
	}
	else if(tempf > 1000.0f)
	{
		tempf /= 1000.0f;
		tempstr2.printf(T("%.2f MB"), tempf);
	}
	else
		tempstr2.printf(T("%.2f kB"), tempf);
	tempstr << tempstr2;
	addAndMakeVisible(fileSize = new Label(T("fileSize"), tempstr));

	tempstr = T("Free space on volume: ");
	tempf = static_cast<double>(file.getBytesFreeOnVolume()/1000);
	if(tempf > 1000000.0f)
	{
		tempf /= 1000000.0f;
		tempstr2.printf(T("%.2f GB"), tempf);
	}
	else if(tempf > 1000.0f)
	{
		tempf /= 1000.0f;
		tempstr2.printf(T("%.2f MB"), tempf);
	}
	else
		tempstr2.printf(T("%.2f kB"), tempf);
	tempstr << tempstr2;
	addAndMakeVisible(fileFreeSize = new Label(T("fileFreeSize"), tempstr));

	tempstr = T("User has write access: ");
	if(file.hasWriteAccess())
		tempstr << "yes";
	else
		tempstr << "no";
	addAndMakeVisible(fileWriteAccess = new Label(T("fileWriteAccess"),
												  tempstr));

	tempstr = T("Last modified: ");
	tempstr << file.getLastModificationTime().toString(true, true);
	addAndMakeVisible(fileModifiedTime = new Label(T("fileModifiedTime"),
												   tempstr));

	tempstr = T("Last accessed: ");
	tempstr << file.getLastAccessTime().toString(true, true);
	addAndMakeVisible(fileAccessedTime = new Label(T("fileAccessedTime"),
												   tempstr));

	tempstr = T("Created: ");
	tempstr << file.getCreationTime().toString(true, true);
	addAndMakeVisible(fileCreationTime = new Label(T("fileCreationTime"),
												   tempstr));
}

//----------------------------------------------------------------------------
PropertiesContents::~PropertiesContents()
{
	deleteAllChildren();
}

//----------------------------------------------------------------------------
void PropertiesContents::resized()
{
	filePath->setBounds(2, 2, (getWidth()-4), 22);

	fileSize->setBounds(2, 34, (getWidth()-4), 22);
	fileFreeSize->setBounds(2, 56, (getWidth()-4), 22);

	fileWriteAccess->setBounds(2, 88, (getWidth()-4), 22);

	fileModifiedTime->setBounds(2, 120, (getWidth()-4), 22);
	fileAccessedTime->setBounds(2, 142, (getWidth()-4), 22);
	fileCreationTime->setBounds(2, 164, (getWidth()-4), 22);
}
