//	FileView.cpp - Component which displays the contents of Phil's current
//				 directory.
//	----------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//	----------------------------------------------------------------------------

#include <juce.h>
#include "FileView.h"
#include "PhilComponent.h"

//------------------------------------------------------------------------------
FileView::FileView(Phil *parentComponent):
Component(T("FileView")),
parent(parentComponent)
{
	
}

//------------------------------------------------------------------------------
FileView::~FileView()
{
	
}

//------------------------------------------------------------------------------
const Image& FileView::getDefaultDirImage()
{
	static bool firstGo = true;
	static Image retval(Image::ARGB, 16, 16, true);

	if(firstGo)
	{
		Path p;
		Graphics g(retval);
		Image tile(Image::ARGB, 16, 16, false);
		PathStrokeType strokeType(1, PathStrokeType::curved);
		GradientBrush basil(Colours::yellow.brighter(2.0f),
							16.0f,
							0.0f,
							Colours::yellow.darker(0.2f),
							16.0f,
							16.0f,
							false);
		Graphics g2(tile);

		p.startNewSubPath(0.0f, 0.0f);
		p.lineTo(6.0f, 0.0f);
		p.lineTo(8.0f, 2.0f);
		p.lineTo(16.0f, 2.0f);
		p.lineTo(16.0f, 15.0f);
		p.lineTo(0.0f, 15.0f);
		p.closeSubPath();

		g2.setBrush(&basil);
		g2.fillRect(0, 0, 16, 16);
		ImageBrush im(&tile, 0, 0, 1.0f);

		g.setBrush(&im);
		g.fillPath(p);
		g.setColour(Colours::lightyellow.brighter(0.15f));
		g.strokePath(p, strokeType);

		firstGo = false;
	}

	return retval;
}

//------------------------------------------------------------------------------
const Image& FileView::getDefaultFileImage()
{
	static bool firstGo = true;
	static Image retval(Image::ARGB, 16, 16, true);

	if(firstGo)
	{
		Path p;
		Graphics g(retval);
		Image tile(Image::ARGB, 16, 16, false);
		PathStrokeType strokeType(1, PathStrokeType::curved);
		GradientBrush basil(Colours::lightblue.brighter(0.1f),
							16.0f,
							0.0f,
							Colours::lightblue.darker(0.2f),
							16.0f,
							16.0f,
							false);
		Graphics g2(tile);

		p.startNewSubPath(2.5f, 0.0f);
		p.lineTo(11.5f, 0.0f);
		p.lineTo(13.5f, 2.0f);
		p.lineTo(13.5f, 15.0f);
		p.lineTo(2.5f, 15.0f);
		p.closeSubPath();

		//basil.paintRectangle(tile, 0, 0, 16, 16, 0, 0);
		g2.setBrush(&basil);
		g2.fillRect(0, 0, 16, 16);
		ImageBrush im(&tile, 0, 0, 1.0f);

		g.setBrush(&im);
		g.fillPath(p);
		g.setColour(Colours::lightblue.brighter(0.25f));
		g.strokePath(p, strokeType);

		firstGo = false;
	}

	return retval;
}
